==> haskell-data-functor-logistic-0.0-143.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-3UPPVwyrfekK2pobmjP1cg
key:                  data-functor-logistic-0.0-3UPPVwyrfekK2pobmjP1cg
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  11de8466755d9b0113686166eba1629d
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-3UPPVwyrfekK2pobmjP1cg
depends:
    base-4.18.2.1 distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-functor-logistic-0.0-144-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-LyamUu8LCsc4QvWOHV0fDI
key:                  data-functor-logistic-0.0-LyamUu8LCsc4QvWOHV0fDI
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  85baa99ce0c924f355d2ce746b9aea01
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-LyamUu8LCsc4QvWOHV0fDI
depends:
    base-4.18.2.1 distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
